@@ -2,12 +2,14 @@
 #  Copyright (c) Microsoft Corporation. All rights reserved.
 #  Licensed under the MIT License (MIT). See LICENSE in the repo root for license information.
 #  ------------------------------------------------------------------------------------------
+import logging
 import torch
 from enum import Enum
 from pathlib import Path
-from typing import Any, Callable, Dict, Generic, Optional, Sequence, Tuple, TypeVar, Union
+from typing import Any, Callable, Dict, Generic, List, Optional, Sequence, Tuple, TypeVar, Union
 
 from pytorch_lightning import LightningDataModule
+from pytorch_lightning.overrides.distributed import UnrepeatedDistributedSampler
 from torch.utils.data import DataLoader, DistributedSampler
 from health_cpath.preprocessing.loading import LoadingParams
 
@@ -110,9 +112,16 @@ class HistoDataModule(LightningDataModule, Generic[_SlidesOrTilesDataset]):
 
     def _get_ddp_sampler(self, dataset: Dataset, stage: ModelKey) -> Optional[DistributedSampler]:
         is_distributed = torch.distributed.is_initialized() and torch.distributed.get_world_size() > 1
-        if is_distributed and not self.pl_replace_sampler_ddp and stage == ModelKey.TRAIN:
+        if is_distributed and not self.pl_replace_sampler_ddp:
             assert self.seed is not None, "seed must be set when using distributed training for reproducibility"
-            return DistributedSampler(dataset, shuffle=True, seed=self.seed)
+            if stage == ModelKey.TRAIN:
+                logging.info("pl_replace_sampler_ddp is False, setting DistributedSampler for training dataloader.")
+                return DistributedSampler(dataset, shuffle=True, seed=self.seed)
+            else:
+                logging.info("pl_replace_sampler_ddp is False, setting UnrepeatedDistributedSampler for validation and "
+                             "test dataloaders. This will ensure that each process gets a unique set of samples. "
+                             "If you want to use DistributedSampler, set pl_replace_sampler_ddp to True.")
+                return UnrepeatedDistributedSampler(dataset, shuffle=False, seed=self.seed)
         return None
 
     def train_dataloader(self) -> DataLoader:
@@ -286,14 +295,7 @@ class SlidesDataModule(HistoDataModule[SlidesDataset]):
         self.loading_params = loading_params
 
     def _load_dataset(self, slides_dataset: SlidesDataset, stage: ModelKey) -> Dataset:
-        base_transform = Compose(
-            [
-                self.loading_params.get_load_roid_transform(),
-                self.tiling_params.get_tiling_transform(bag_size=self.bag_sizes[stage], stage=stage),
-                self.tiling_params.get_extract_coordinates_transform(),
-                self.tiling_params.get_split_transform(),
-            ]
-        )
+        base_transform = Compose(self.get_tiling_transforms(stage=stage))
         if self.transforms_dict and self.transforms_dict[stage]:
             transforms = Compose([base_transform, self.transforms_dict[stage]]).flatten()
         else:
@@ -318,3 +320,13 @@ class SlidesDataModule(HistoDataModule[SlidesDataset]):
             generator=generator,
             **dataloader_kwargs,
         )
+
+    def get_tiling_transforms(self, stage: ModelKey) -> List[Callable]:
+        """Returns the list of transforms to apply to the dataset to perform tiling on the fly. The transforms are
+        applied in the order they are returned by this method. To add additional transforms, override this method."""
+        return [
+            self.loading_params.get_load_roid_transform(),
+            self.tiling_params.get_tiling_transform(bag_size=self.bag_sizes[stage], stage=stage),
+            self.tiling_params.get_extract_coordinates_transform(),
+            self.tiling_params.get_split_transform(),
+        ]
